summaryrefslogtreecommitdiff
path: root/src/cpu/smt.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/cpu/smt.hh')
-rw-r--r--src/cpu/smt.hh4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/cpu/smt.hh b/src/cpu/smt.hh
index cac1a8fd5..d90a1833a 100644
--- a/src/cpu/smt.hh
+++ b/src/cpu/smt.hh
@@ -52,10 +52,10 @@ extern int maxThreadsPerCPU;
/**
* Changes the status and priority of the thread with the given number.
* @param thread_number The thread to change.
* @param activate The new active status.
* @param priority The new priority.
*/
-void change_thread_state(int thread_number, int activate, int priority);
+void change_thread_state(ThreadID tid, int activate, int priority);
#endif // __SMT_HH__
@@ -52,10 +52,10 @@ extern int maxThreadsPerCPU;
/**
* Changes the status and priority of the thread with the given number.
- * @param thread_number The thread to change.
+ * @param tid The thread to change.
* @param activate The new active status.
* @param priority The new priority.